referrerpolicy=no-referrer-when-downgrade

NewRaise

Type Alias NewRaise 

pub type NewRaise<T> = StorageValue<_GeneratedPrefixForStorageNewRaise<T>, Vec<Id>, ValueQuery>;
The funds that have had additional contributions during the last block. This is used in order to determine which funds should submit new or updated bids.

Storage type is StorageValue with value type Vec < ParaId >.

Aliased Type

pub struct NewRaise<T>(/* private fields */);